@@ -41,7 +41,7 @@ class  ResourceSelect : public Handler
 {
     Q_OBJECT
 public:
-    bool parseStream() Q_DECL_OVERRIDE;
+    bool parseStream() override;
 };
 
 } // namespace Server
