@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2011-2017 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Library General Public License as published by
@@ -34,7 +34,7 @@ RecentCollectionAction::RecentCollectionAction(Akonadi::StandardActionManager::T
     : QObject(menu)
     , mMenu(menu)
     , mModel(model)
-    , mRecentAction(0)
+    , mRecentAction(nullptr)
 {
     mAkonadiConfig = KSharedConfig::openConfig(QStringLiteral("akonadikderc"));
     KConfigGroup group(mAkonadiConfig, QStringLiteral("Recent Collections"));
@@ -91,7 +91,7 @@ void RecentCollectionAction::fillRecentCollection(Akonadi::StandardActionManager
 QString RecentCollectionAction::actionName(QModelIndex index)
 {
     QString name = index.data().toString();
-    name.replace(QStringLiteral("&"), QStringLiteral("&&"));
+    name.replace(QLatin1Char('&'), QStringLiteral("&&"));
 
     index = index.parent();
     QString topLevelName;
@@ -102,7 +102,7 @@ QString RecentCollectionAction::actionName(QModelIndex index)
     if (topLevelName.isEmpty()) {
         return QStringLiteral("%1").arg(name);
     } else {
-        topLevelName.replace(QStringLiteral("&"), QStringLiteral("&&"));
+        topLevelName.replace(QLatin1Char('&'), QStringLiteral("&&"));
         return QStringLiteral("%1 - %2").arg(name, topLevelName);
     }
 }
